(* some command line argument state *)
let patches = ref []
let add_patch patch = patches := patch :: !patches
let filesdir = ref ""
let delete = ref false

let speclist = [
    ("-patch", Arg.String add_patch, "<patch> includes the given patch");
    ("-filesdir", Arg.Set_string filesdir,
                    "<dir> includes the given heirarchy of files");
    ("-delete", Arg.Set delete, "deletes an old package that is in the way");
]

(* some more command line argument state *)
let anonargs = ref []
let anonfun arg = anonargs := arg :: !anonargs

let usage_msg = "Usage: godor [OPTIONS] CONTROL GODI_LOCALBASE"

let () =
    Arg.parse speclist anonfun usage_msg;
    match (List.rev !anonargs) with
      [ control_file; godi_localbase ] ->
        (* parse control file *)
        print_endline ("Parsing control file..");
        Syntax.current_file := control_file;
        let chan = open_in control_file in
        let lexbuf = Lexing.from_channel chan in
        let control =
            Syntax.handle
                (fun () -> Controlparser.spec Controllexer.token lexbuf)
        in
        close_in chan;

        if !filesdir = "" then
          Control.write_package ~godi_localbase ~control_file ~control
                                ~patches:!patches ~delete:!delete ()
        else
          Control.write_package ~godi_localbase ~control_file ~control
                                ~patches:!patches ~delete:!delete
                                ~filesdir:!filesdir ()
    | _ -> Arg.usage speclist usage_msg
