#load "syntax.cmo"
#load "controlparser.cmo"
#load "controllexer.cmo"

let lex file =
    let chan = open_in file in
    let lexbuf = Lexing.from_channel chan in
    let rec lex_aux () =
        match Controllexer.token lexbuf with
            | Controlparser.EOF -> []
            | token -> token :: lex_aux ()
    in
    let ret = lex_aux () in
    close_in chan;
    ret

let lex_open file =
    let chan = open_in file in
    let lexbuf = Lexing.from_channel chan in
    Controllexer.reset (); lexbuf

module C = Controllexer

let print_positions pos1 pos2 =
    let lnum1 = pos1.Lexing.pos_lnum in
    let lnum2 = pos2.Lexing.pos_lnum in
    if lnum1 = lnum2 then assert (pos1.Lexing.pos_bol = pos2.Lexing.pos_bol);
    let column1 = pos1.Lexing.pos_cnum - pos1.Lexing.pos_bol in
    let column2 = pos2.Lexing.pos_cnum - pos2.Lexing.pos_bol in
    if lnum1 = lnum2 then
      begin
        print_string ("line " ^ string_of_int lnum1);
        if column1 = column2 then
            print_string (" character " ^ string_of_int column1)
        else
            (print_string " characters ";
             print_int column1;
             print_string "-";
             print_int column2)
      end
    else
      begin
        print_string ("line " ^ string_of_int lnum1);
        print_string " character ";
        print_int column1;
        print_string " - ";
        print_string ("line " ^ string_of_int lnum2);
        print_string " character ";
        print_int column2
      end

(*
let _ =
    try
        lex "simple-control.format"
    with
        Controllexer.LexError (pos1, pos2, message) ->
            print_string "Lexing error at ";
            print_positions pos1 pos2;
            print_string ":";
            print_newline ();
            print_endline message;
            exit 1
*)

let parse file =
    let lexbuf = lex_open file in
    Controlparser.spec Controllexer.token lexbuf

let _ =
    try
        (*parse "simple-control.format"*)
    with
        Syntax.Error (pos1, pos2, message) ->
            print_string "Syntax error at ";
            print_positions pos1 pos2;
            print_string ":";
            print_newline ();
            print_endline message;
            exit 1
